@@ -29,6 +29,8 @@
 #' @param method character or function.
 #' @param method.args,glance.args list of arguments to pass to \code{method}
 #'   and to [generics::glance()], respectively.
+#' @param n.min integer Minimum number of distinct values in the explanatory
+#'   variable (on the rhs of formula) for fitting to the attempted.
 #' @param label.x,label.y \code{numeric} with range 0..1 "normalized parent
 #'   coordinates" (npc units) or character if using \code{geom_text_npc()} or
 #'   \code{geom_label_npc()}. If using \code{geom_text()} or \code{geom_label()}
@@ -190,6 +192,7 @@
 stat_fit_glance <- function(mapping = NULL, data = NULL, geom = "text_npc",
                             method = "lm",
                             method.args = list(formula = y ~ x),
+                            n.min = 2L,
                             glance.args = list(),
                             label.x = "left", label.y = "top",
                             hstep = 0,
@@ -204,6 +207,7 @@ stat_fit_glance <- function(mapping = NULL, data = NULL, geom = "text_npc",
       rlang::list2(method = method,
                    method.args = method.args,
                    glance.args = glance.args,
+                   n.min = n.min,
                    label.x = label.x,
                    label.y = label.y,
                    hstep = hstep,
@@ -225,6 +229,7 @@ fit_glance_compute_group_fun <- function(data,
                                          scales,
                                          method,
                                          method.args,
+                                         n.min,
                                          glance.args,
                                          label.x,
                                          label.y,
@@ -234,21 +239,20 @@ fit_glance_compute_group_fun <- function(data,
 
   force(data) # needed because it appears only wihtin quote()
 
-  if (length(unique(data$x)) < 2) {
+  if (length(unique(data$x)) < n.min) {
     # Not enough data to perform fit
     return(data.frame())
   }
 
-  group.idx <- abs(data$group[1])
-  if (length(label.x) >= group.idx) {
-    label.x <- label.x[group.idx]
-  } else if (length(label.x) > 0) {
-    label.x <- label.x[1]
-  }
-  if (length(label.y) >= group.idx) {
-    label.y <- label.y[group.idx]
-  } else if (length(label.y) > 0) {
-    label.y <- label.y[1]
+  if (is.integer(data$group)) {
+    group.idx <- abs(data$group[1])
+  } else if (is.character(data$group) &&
+             grepl("^(-1|[0-9]+).*$", data$group[1])) {
+    # likely that 'gganimate' has set the groups for scenes
+    # we assume first characters give the original group
+    group.idx <- abs(as.numeric(gsub("^(-1|[0-9]+).*$", "\\1", data$group[1])))
+  } else {
+    group.idx <- NA_integer_
   }
 
   if (length(label.x) >= group.idx) {
@@ -377,6 +381,7 @@ fit_glance_compute_group_fun <- function(data,
 StatFitGlance <-
   ggplot2::ggproto("StatFitGlance", ggplot2::Stat,
                    compute_group = fit_glance_compute_group_fun,
+                   dropped_aes = "weight",
                    default_aes =
                      ggplot2::aes(npcx = after_stat(npcx),
                                   npcy = after_stat(npcy),
@@ -417,6 +422,8 @@ StatFitGlance <-
 #' @param method character or function.
 #' @param method.args,augment.args list of arguments to pass to \code{method}
 #'   and to to \code{broom:augment}.
+#' @param n.min integer Minimum number of distinct values in the explanatory
+#'   variable (on the rhs of formula) for fitting to the attempted.
 #' @param level numeric Level of confidence interval to use (0.95 by default)
 #' @param y.out character (or numeric) index to column to return as \code{y}.
 #'
@@ -551,13 +558,13 @@ StatFitGlance <-
 #' if (broom.installed)
 #'   ggplot(mtcars, aes(x = disp, y = mpg)) +
 #'     geom_point() +
-#'     stat_fit_augment(method = "rq",
-#'                     label.y = "bottom")
+#'     stat_fit_augment(method = "rq")
 #'
 #'
 stat_fit_augment <- function(mapping = NULL, data = NULL, geom = "smooth",
                              method = "lm",
                              method.args = list(formula = y ~ x),
+                             n.min = 2L,
                              augment.args = list(),
                              level = 0.95,
                              y.out = ".fitted",
@@ -571,6 +578,7 @@ stat_fit_augment <- function(mapping = NULL, data = NULL, geom = "smooth",
       rlang::list2(method = method,
                    method.args = method.args,
                    augment.args = augment.args,
+                   n.min = n.min,
                    level = level,
                    y.out = y.out,
                    na.rm = na.rm,
@@ -589,6 +597,7 @@ fit_augment_compute_group_fun <- function(data,
                                     scales,
                                     method,
                                     method.args,
+                                    n.min,
                                     augment.args,
                                     level,
                                     y.out,
@@ -603,7 +612,7 @@ fit_augment_compute_group_fun <- function(data,
   force(data)
   data <- na.omit(data)
 
-  if (length(unique(data[["x"]])) < 2) {
+  if (length(unique(data[["x"]])) < n.min) {
     # Not enough data to perform fit
     return(data.frame())
   }
@@ -664,6 +673,7 @@ StatFitAugment <-
   ggplot2::ggproto("StatFitAugment",
                    ggplot2::Stat,
                    compute_group = fit_augment_compute_group_fun,
+                   dropped_aes = "weight",
                    default_aes =
                      ggplot2::aes(ymax = after_stat(y + .se.fit * t.value),
                                   ymin = after_stat(y - .se.fit * t.value)),
@@ -704,6 +714,8 @@ StatFitAugment <-
 #' @param method character or function.
 #' @param method.args,tidy.args list of arguments to pass to \code{method},
 #'   and to [generics::tidy], respectively.
+#' @param n.min integer Minimum number of distinct values in the explanatory
+#'   variable (on the rhs of formula) for fitting to the attempted.
 #' @param label.x,label.y \code{numeric} with range 0..1 or character.
 #'   Coordinates to be used for positioning the output, expressed in "normalized
 #'   parent coordinates" or character string. If too short they will be
@@ -820,7 +832,7 @@ StatFitAugment <-
 #' # Regression by panel example
 #' if (broom.installed)
 #'   ggplot(mtcars, aes(x = disp, y = mpg)) +
-#'     stat_smooth(method = "lm") +
+#'     stat_smooth(method = "lm", formula = y ~ x) +
 #'     geom_point(aes(colour = factor(cyl))) +
 #'     stat_fit_tidy(method = "lm",
 #'                   label.x = "right",
@@ -832,7 +844,7 @@ StatFitAugment <-
 #' # Regression by group example
 #' if (broom.installed)
 #'   ggplot(mtcars, aes(x = disp, y = mpg, colour = factor(cyl))) +
-#'     stat_smooth(method = "lm") +
+#'     stat_smooth(method = "lm", formula = y ~ x) +
 #'     geom_point() +
 #'     stat_fit_tidy(method = "lm",
 #'                   label.x = "right",
@@ -844,7 +856,7 @@ StatFitAugment <-
 #' # Weighted regression example
 #' if (broom.installed)
 #'   ggplot(mtcars, aes(x = disp, y = mpg, weight = cyl)) +
-#'     stat_smooth(method = "lm") +
+#'     stat_smooth(method = "lm", formula = y ~ x) +
 #'     geom_point(aes(colour = factor(cyl))) +
 #'     stat_fit_tidy(method = "lm",
 #'                   label.x = "right",
@@ -853,22 +865,10 @@ StatFitAugment <-
 #'                                                 after_stat(x_estimate),
 #'                                                 after_stat(x_p.value))))
 #'
-#' # Correlation test
-#' if (broom.installed)
-#'   ggplot(mtcars, aes(x = disp, y = mpg)) +
-#'     stat_smooth(method = "lm") +
-#'     geom_point() +
-#'     stat_fit_tidy(method = "cor.test",
-#'                   label.y = "bottom",
-#'                   method.args = list(formula = ~ x + y),
-#'                   mapping = aes(label = sprintf("R = %.3g\np-value = %.3g",
-#'                                                 after_stat(`_estimate`),
-#'                                                 after_stat(`_p.value`))))
-#'
 #' # Quantile regression
 #' if (broom.installed)
 #'   ggplot(mtcars, aes(x = disp, y = mpg)) +
-#'     stat_smooth(method = "lm") +
+#'     stat_smooth(method = "lm", formula = y ~ x) +
 #'     geom_point() +
 #'     stat_fit_tidy(method = "rq",
 #'                   label.y = "bottom",
@@ -881,6 +881,7 @@ StatFitAugment <-
 stat_fit_tidy <- function(mapping = NULL, data = NULL, geom = "text_npc",
                           method = "lm",
                           method.args = list(formula = y ~ x),
+                          n.min = 2L,
                           tidy.args = list(),
                           label.x = "left", label.y = "top",
                           hstep = 0,
@@ -895,6 +896,7 @@ stat_fit_tidy <- function(mapping = NULL, data = NULL, geom = "text_npc",
     params =
       rlang::list2(method = method,
                    method.args = method.args,
+                   n.min = n.min,
                    tidy.args = tidy.args,
                    label.x = label.x,
                    label.y = label.y,
@@ -922,6 +924,7 @@ fit_tidy_compute_group_fun <- function(data,
                                        scales,
                                        method,
                                        method.args,
+                                       n.min,
                                        tidy.args,
                                        label.x,
                                        label.y,
@@ -930,12 +933,22 @@ fit_tidy_compute_group_fun <- function(data,
                                        sanitize.names,
                                        npc.used) {
   force(data)
-  if (length(unique(data$x)) < 2) {
+  if (length(unique(data$x)) < n.min) {
     # Not enough data to perform fit
     return(data.frame())
   }
 
-  group.idx <- abs(data$group[1])
+  if (is.integer(data$group)) {
+    group.idx <- abs(data$group[1])
+  } else if (is.character(data$group) &&
+             grepl("^(-1|[0-9]+).*$", data$group[1])) {
+    # likely that 'gganimate' has set the groups for scenes
+    # we assume first characters give the original group
+    group.idx <- abs(as.numeric(gsub("^(-1|[0-9]+).*$", "\\1", data$group[1])))
+  } else {
+    group.idx <- NA_integer_
+  }
+
   if (length(label.x) >= group.idx) {
     label.x <- label.x[group.idx]
   } else if (length(label.x) > 0) {
@@ -1074,6 +1087,7 @@ fit_tidy_compute_group_fun <- function(data,
 StatFitTidy <-
   ggplot2::ggproto("StatFitTidy", ggplot2::Stat,
                    compute_group = fit_tidy_compute_group_fun,
+                   dropped_aes = "weight",
                    default_aes =
                      ggplot2::aes(npcx = after_stat(npcx),
                                   npcy = after_stat(npcy),
