@@ -44,6 +44,8 @@
 #'   and return a model fit object of class \code{rq} or \code{rqs}.
 #' @param method.args named list with additional arguments passed to \code{rq()}
 #'   or to a function passed as argument to \code{method}.
+#' @param n.min integer Minimum number of observations needed for fiting a
+#'   the model.
 #' @param eq.with.lhs If \code{character} the string is pasted to the front of
 #'   the equation label before parsing or a \code{logical} (see note).
 #' @param eq.x.rhs \code{character} this string will be used as replacement for
@@ -119,6 +121,15 @@
 #'   respects the grammar of graphics. This helps ensure that the model is
 #'   fitted to the same data as plotted in other layers.
 #'
+#'   Function \code{\link[quantreg]{rq}} does not support singular fits, in
+#'   contrast to \code{lm}.
+#'
+#'   The minimum number of observations with distinct values in the explanatory
+#'   variable can be set through parameter \code{n.min}. The default \code{n.min
+#'   = 3L} is the smallest usable value. However, model fits with very few
+#'   observations are of little interest and using larger values of \code{n.min}
+#'   than the default is usually wise.
+#'
 #' @references Written as an answer to question 65695409 by Mark Neal at
 #'   Stackoverflow.
 #'
@@ -128,6 +139,11 @@
 #'   \code{numeric} variables. In addition, the aesthetics understood by the
 #'   geom used (\code{"text"} by default) are understood and grouping respected.
 #'
+#' @return A data frame, with one row per quantile and columns as described
+#'   under \strong{Computed variables}. In cases when the number of observations
+#'   is less than \code{n.min} a data frame with no rows or columns is returned
+#'   rendered as an empty/invisible plot layer.
+#'
 #' @section Computed variables:
 #' If output.type different from \code{"numeric"} the returned tibble contains
 #' columns below in addition to a modified version of the original \code{group}:
@@ -384,6 +400,7 @@ stat_quant_eq <- function(mapping = NULL, data = NULL,
                          quantiles = c(0.25, 0.5, 0.75),
                          method = "rq:br",
                          method.args = list(),
+                         n.min = 3L,
                          eq.with.lhs = TRUE,
                          eq.x.rhs = NULL,
                          coef.digits = 3,
@@ -432,6 +449,7 @@ stat_quant_eq <- function(mapping = NULL, data = NULL,
                    quantiles = quantiles,
                    method = method,
                    method.args = method.args,
+                   n.min = n.min,
                    eq.with.lhs = eq.with.lhs,
                    eq.x.rhs = eq.x.rhs,
                    coef.digits = coef.digits,
@@ -467,6 +485,7 @@ quant_eq_compute_group_fun <- function(data,
                                        quantiles,
                                        method,
                                        method.args,
+                                       n.min,
                                        weight,
                                        eq.with.lhs,
                                        eq.x.rhs,
@@ -546,7 +565,17 @@ quant_eq_compute_group_fun <- function(data,
     grp.label <- ""
   }
 
-  group.idx <- abs(data[["group"]][1])
+  if (is.integer(data$group)) {
+    group.idx <- abs(data$group[1])
+  } else if (is.character(data$group) &&
+             grepl("^(-1|[0-9]+).*$", data$group[1])) {
+    # likely that 'gganimate' has set the groups for scenes
+    # we assume first characters give the original group
+    group.idx <- abs(as.numeric(gsub("^(-1|[0-9]+).*$", "\\1", data$group[1])))
+  } else {
+    group.idx <- NA_integer_
+  }
+
   if (length(label.x) >= group.idx) {
     label.x <- label.x[group.idx]
   } else if (length(label.x) > 0) {
@@ -559,18 +588,12 @@ quant_eq_compute_group_fun <- function(data,
   }
 
   if (orientation == "x") {
-    if (length(unique(data[["x"]])) < 2) {
-      warning("Not enough data to perform fit for group ",
-              group.idx, "; computing mean instead.",
-              call. = FALSE)
-      formula = y ~ 1
+    if (length(unique(data$x)) < n.min) {
+      return(data.frame())
     }
   } else if (orientation == "y") {
-    if (length(unique(data[["y"]])) < 2) {
-      warning("Not enough data to perform fit for group ",
-              group.idx, "; computing mean instead.",
-              call. = FALSE)
-      formula = x ~ 1
+    if (length(unique(data$y)) < n.min) {
+      return(data.frame())
     }
   }
 
@@ -729,7 +752,7 @@ quant_eq_compute_group_fun <- function(data,
     if (output.type == "expression") {
       z <- tibble::tibble(eq.label = eq.char,
                           AIC.label = paste("AIC", AIC.char, sep = "~`=`~"),
-                          rho.label = paste("rho", AIC.char, sep = "~`=`~"),
+                          rho.label = paste("rho", rho.char, sep = "~`=`~"),
                           n.label = paste("italic(n)~`=`~", n, sep = ""),
                           grp.label = if (any(grp.label != ""))
                                          paste(grp.label,
@@ -745,7 +768,7 @@ quant_eq_compute_group_fun <- function(data,
     } else if (output.type %in% c("latex", "tex", "text", "tikz")) {
       z <- tibble::tibble(eq.label = eq.char,
                           AIC.label = paste("AIC", AIC.char, sep = " = "),
-                          rho.label = paste("rho", AIC.char, sep = " = "),
+                          rho.label = paste("rho", rho.char, sep = " = "),
                           n.label = paste("n = ", n, sep = ""),
                           grp.label = paste(grp.label,
                                             sprintf_dm("q = %.2f", quantiles, decimal.mark = decimal.mark)),
@@ -757,7 +780,7 @@ quant_eq_compute_group_fun <- function(data,
     } else if (output.type == "markdown") {
       z <- tibble::tibble(eq.label = eq.char,
                           AIC.label = paste("AIC", AIC.char, sep = " = "),
-                          rho.label = paste("rho", AIC.char, sep = " = "),
+                          rho.label = paste("rho", rho.char, sep = " = "),
                           n.label = paste("_n_ = ", n, sep = ""),
                           grp.label = paste(grp.label,
                                             sprintf_dm("q = %.2f", quantiles, decimal.mark = decimal.mark)),
